import { PrismaClient } from '@prisma/client'
import { ErrorDescEnum, HttpError } from '../classes/HttpError'
import dayjs from 'dayjs'

export default async (prisma: PrismaClient, issueDateRaw: string, suffix: string) => {
	console.log('Deleting invoice', issueDateRaw, suffix)
	const issueDate = dayjs(issueDateRaw, 'YYYYMMDD').startOf('day').toDate()
	const invoice = await prisma.invoice.findFirst({
		where: {
			invoice_date: issueDate,
			invoice_suffix_code: parseInt(suffix)
		}
	})

	if (!invoice) throw new HttpError(ErrorDescEnum.item_not_found, 404, ['invoice'])
	
	await prisma.invoiceItem.deleteMany({
		where: {
			invoice_suffix_code: parseInt(suffix),
			invoice_date: issueDate
		}
	})

	await prisma.invoice.delete({
		where: {
			invoice_date_invoice_suffix_code: {
				invoice_date: issueDate,
				invoice_suffix_code: parseInt(suffix)
			}
		}
	})
}