import { PrismaClient } from '@prisma/client'
import { ErrorDescEnum, HttpError } from '../classes/HttpError'

export default async (prisma: PrismaClient, id: string) => {
	const payer = await prisma.payer.findFirst({
		where: {
			payer_id: parseInt(id)
		}
	})

	if (!payer) throw new HttpError(ErrorDescEnum.item_not_found, 404, ['payer'])

	// 删除所有与付款人相关的发票，包括发票项目
	const invoices = await prisma.invoice.findMany({
		where: {
			payer_id: parseInt(id)
		}
	})

	for (let i in invoices) {
		await prisma.invoiceItem.deleteMany({
			where: {
				invoice_suffix_code: invoices[i].invoice_suffix_code,
				invoice_date: invoices[i].invoice_date
			}
		})

		await prisma.invoice.delete({
			where: {
				invoice_date_invoice_suffix_code: {
					invoice_date: invoices[i].invoice_date,
					invoice_suffix_code: invoices[i].invoice_suffix_code
				}
			}
		})
	}

	// 删除付款人
	await prisma.payer.delete({
		where: {
			payer_id: parseInt(id)
		}
	})
}