import dayjs from 'dayjs'
import { PrismaClient } from '@prisma/client'
import { ErrorDescEnum, HttpError } from '../classes/HttpError'

export default async (prisma: PrismaClient, issueDateRaw: string, suffix: string, note?: string) => {
	const issueDate = dayjs(issueDateRaw, 'YYYYMMDD').startOf('day').toDate()
	const invoice = await prisma.invoice.findFirst({
		where: {
			invoice_date: issueDate,
			invoice_suffix_code: parseInt(suffix, 10)
		}
	})

	if (!invoice) throw new HttpError(ErrorDescEnum.item_not_found, 404, ['invoice'])

	await prisma.invoice.update({
		where: {
			invoice_date_invoice_suffix_code: {
				invoice_date: issueDate,
				invoice_suffix_code: parseInt(suffix, 10)
			}
		},
		data: {
			invoice_note: note
		}
	})

	return
}