import { PrismaClient } from '@prisma/client'
import { ErrorDescEnum, HttpError } from '../classes/HttpError'

export default async function updatePayer(prisma: PrismaClient, id: string, name: string, address: string[], email: string, abn?: string) {
	// 验证 ABN 是否已存在
	const existingPayer = await prisma.payer.findFirst({
		where: {
			payer_abn: abn
		}
	})
	if (existingPayer && existingPayer.payer_id !== parseInt(id)) throw new HttpError(ErrorDescEnum.item_exists, 400, ['abn'])

	// 验证付款人是否存在
	const payerExists = await prisma.payer.findFirst({
		where: {
			payer_id: parseInt(id)
		}
	})
	if (!payerExists) throw new HttpError(ErrorDescEnum.item_not_found, 404, ['payer'])

	// 更新付款人
	const payer = await prisma.payer.update({
		where: {
			payer_id: parseInt(id)
		},
		data: {
			payer_name: name,
			payer_address: address.join('\n'),
			payer_email: email,
			payer_abn: abn
		}
	})
	return payer
}